# turbines

A static site generator built with Jinja2.

Inspired by [Cactus](https://github.com/koenbok/Cactus), a project that is no longer maintained.

## What is turbines?

Turbines is a static site generator that allows you to create websites using Jinja-based HTML templates and markdown files. Turbines makes it easy to deploy your site to services like Cloudflare Pages or AWS S3. It supports live reloading during development.

## Usage

To install turbines, run:

```bash
pip install turbines
```

or

```bash
uv add turbines
```

To create a new site, run:

```bash
turbines create mysite
cd mysite
```

To build the site, run:

```bash
turbines build
```

To serve the site with live reloading, run:

```bash
turbines serve
```

## Examples

None yet. Coming soon!

## Compatibility

Turbines is built with Python 3.12.
